Crate winio_handle

Crate winio_handle 

Handles for winio.

Window

A window handle represents a window chrome, such as title bar and borders. It interoperates with the underlying windowing system, such as Win32 or WinUI on Windows, and AppKit on macOS.

A window is usually both a window and a container, so it implements both AsWindow and AsContainer traits.

PlatformNative Type
Win32HWND
WinUIWindow
QtQWidget
GtkGtkWindow
AppKitNSWindow
UIKitUIWindow
AndroidGameActivity

Platform specific

Container

A container handle represents a container, such as a window or a scroll view.

PlatformNative Type
Win32HWND
WinUICanvas
QtQWidget
GtkGtkFixed
AppKitNSView
UIKitUIView
AndroidFrameLayout

Platform specific

  • WinUI: The parent of all widgets must be a Canvas, and the widget will be set to center alignment. The window of WinUI contains a Canvas.
  • Gtk: The parent of all widgets must be a GtkFixed. The window of Gtk contains a GtkScrolledWindow, and the scrolled window contains a GtkFixed.

Widget

A widget handle represents a widget, such as a button or a text box.

PlatformNative Type
Win32HWND
WinUIFrameworkElement
QtQWidget
GtkGtkWidget
AppKitNSView
UIKitUIView
AndroidView

Structs

BorrowedContainer
Raw container handle.
BorrowedWidget
Raw widget handle.
BorrowedWindow
Raw window handle.

Traits

AsContainer
Trait to borrow the container handle.
AsWidget
Trait to borrow the widget handle.
AsWindow
Trait to borrow the window handle.