Handles for winio.
Window
A window handle represents a window chrome, such as title bar and borders. It interoperates with the underlying windowing system, such as Win32 or WinUI on Windows, and AppKit on macOS.
A window is usually both a window and a container, so it implements both
AsWindow and AsContainer traits.
| Platform | Native Type |
|---|---|
| Win32 | HWND |
| WinUI | Window |
| Qt | QWidget |
| Gtk | GtkWindow |
| AppKit | NSWindow |
| UIKit | UIWindow |
| Android | GameActivity |
Platform specific
- Qt: The window is a
QMainWindow.
Container
A container handle represents a container, such as a window or a scroll view.
| Platform | Native Type |
|---|---|
| Win32 | HWND |
| WinUI | Canvas |
| Qt | QWidget |
| Gtk | GtkFixed |
| AppKit | NSView |
| UIKit | UIView |
| Android | FrameLayout |
Platform specific
- WinUI: The parent of all widgets must be a
Canvas, and the widget will be set to center alignment. The window of WinUI contains aCanvas. - Gtk: The parent of all widgets must be a
GtkFixed. The window of Gtk contains aGtkScrolledWindow, and the scrolled window contains aGtkFixed.
Widget
A widget handle represents a widget, such as a button or a text box.
Structs
- Borrowed
Container - Raw container handle.
- Borrowed
Widget - Raw widget handle.
- Borrowed
Window - Raw window handle.
Traits
- AsContainer
- Trait to borrow the container handle.
- AsWidget
- Trait to borrow the widget handle.
- AsWindow
- Trait to borrow the window handle.